aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBruno Cabral <bcabral@uw.edu>2014-03-30 13:42:47 +0000
committerBruno Cabral <bcabral@uw.edu>2014-03-30 13:42:47 +0000
commitc20cf66237cb0e1b608427fd95ce95a13f6ebeb4 (patch)
treebd3405f558c74b2df19722c2ba0679b0d20c3f4a
parente63b1859b1c284193b8a12221001d48069079b2c (diff)
friend is a reserved work in C++. Rename to friend_id.
-rw-r--r--src/include/gnunet_friends_lib.h8
-rw-r--r--src/topology/friends.c6
2 files changed, 7 insertions, 7 deletions
diff --git a/src/include/gnunet_friends_lib.h b/src/include/gnunet_friends_lib.h
index dda1d32452..a607876547 100644
--- a/src/include/gnunet_friends_lib.h
+++ b/src/include/gnunet_friends_lib.h
@@ -33,10 +33,10 @@
* Signature of a function called on each friend found.
*
* @param cls closure
* @param friend peer identity of the friend
*/
typedef void (*GNUNET_FRIENDS_Callback)(void *cls,
- const struct GNUNET_PeerIdentity *friend);
+ const struct GNUNET_PeerIdentity *friend_id);
/**
@@ -84,12 +84,12 @@ GNUNET_FRIENDS_write_stop (struct GNUNET_FRIENDS_Writer *w);
* Add a friend to the friends file.
*
* @param w write handle
* @param friend friend to add
* @return #GNUNET_OK on success, #GNUNET_SYSERR on error
*/
int
GNUNET_FRIENDS_write (struct GNUNET_FRIENDS_Writer *w,
- const struct GNUNET_PeerIdentity *friend);
+ const struct GNUNET_PeerIdentity *friend_id);
#endif
@@ -33,10 +33,10 @@
*
* @param cls closure
- * @param friend peer identity of the friend
+ * @param friend_id peer identity of the friend
*/
typedef void (*GNUNET_FRIENDS_Callback)(void *cls,
@@ -84,12 +84,12 @@ GNUNET_FRIENDS_write_stop (struct GNUNET_FRIENDS_Writer *w);
*
* @param w write handle
- * @param friend friend to add
+ * @param friend_id friend to add
* @return #GNUNET_OK on success, #GNUNET_SYSERR on error
*/
diff --git a/src/topology/friends.c b/src/topology/friends.c
index f79ee77ca5..348123fe6f 100644
--- a/src/topology/friends.c
+++ b/src/topology/friends.c
@@ -194,18 +194,18 @@ GNUNET_FRIENDS_write_stop (struct GNUNET_FRIENDS_Writer *w)
* Add a friend to the friends file.
*
* @param w write handle
* @param friend friend to add
* @return #GNUNET_OK on success, #GNUNET_SYSERR on error
*/
int
GNUNET_FRIENDS_write (struct GNUNET_FRIENDS_Writer *w,
- const struct GNUNET_PeerIdentity *friend)
+ const struct GNUNET_PeerIdentity *friend_id)
{
char *buf;
char *ret;
size_t slen;
- ret = GNUNET_CRYPTO_eddsa_public_key_to_string (&friend->public_key);
+ ret = GNUNET_CRYPTO_eddsa_public_key_to_string (&friend_id->public_key);
GNUNET_asprintf (&buf,
"%s\n",
ret);
@@ -194,18 +194,18 @@ GNUNET_FRIENDS_write_stop (struct GNUNET_FRIENDS_Writer *w)
*
* @param w write handle
- * @param friend friend to add
+ * @param friend_id friend to add
* @return #GNUNET_OK on success, #GNUNET_SYSERR on error
*/